SoundFromAssetSpan class

A Sound from a span of assetKey.

Inheritance

Constructors

SoundFromAssetSpan({required String assetKey, required int offset, required int length, required bool destroy, double volume = 0.7, AssetBundle? assetBundle, bool looping = false, LoadMode loadMode = LoadMode.memory, Duration loopingStart = Duration.zero, bool paused = false, SoundPosition position = unpanned, double relativePlaySpeed = 1.0})
Create an instance.
const

Properties

assetBundle AssetBundle?
The asset bundle to use.
finalinherited
assetKey String
The asset key to use.
finalinherited
destroy bool
Whether or not this sound should be destroyed after playing.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
internalUri String
Include offset and length in the assetKey.
no setteroverride
length int
The length of the sound.
final
loadMode → LoadMode
The load mode to use.
finalinherited
looping bool
Whether this sound should loop.
finalinherited
loopingStart Duration
The point where this sound should start loading.
finalinherited
offset int
The starting offset.
final
paused bool
Whether this sound should start paused.
finalinherited
position SoundPosition
The position for this sound.
finalinherited
relativePlaySpeed double
The playback rate to use.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
volume double
The volume to play at.
finalinherited

Methods

copyWith({int? offset, int? length, String? assetKey, AssetBundle? assetBundle, LoadMode? loadMode, bool? destroy, double? volume, bool? looping, Duration? loopingStart, SoundPosition? position, bool? paused, double? relativePlaySpeed}) SoundFromAsset
Copy this instance.
override
load() Future<AudioSource>
Load this sound.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited