SoundFromFile class
- Inheritance
-
- Object
- Sound
- LoadableSound
- SoundFromFile
Constructors
- SoundFromFile({required File file, required bool destroy, LoadMode loadMode = LoadMode.memory, bool looping = false, Duration loopingStart = Duration.zero, bool paused = false, SoundPosition position = unpanned, double volume = 0.7, double relativePlaySpeed = 1.0})
-
Create an instance.
const
Properties
- destroy → bool
-
Whether or not this sound should be destroyed after playing.
finalinherited
- file → File
-
The file to load from.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalUri → String
-
Return the path of file.
no setteroverride
- loadMode → LoadMode
-
The load mode to use.
finalinherited
- looping → bool
-
Whether this sound should loop.
finalinherited
- loopingStart → Duration
-
The point where this sound should start loading.
finalinherited
- paused → bool
-
Whether this sound should start paused.
finalinherited
- position → SoundPosition
-
The position for this sound.
finalinherited
- relativePlaySpeed → double
-
The playback rate to use.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volume → double
-
The volume to play at.
finalinherited
Methods
-
copyWith(
{File? file, LoadMode? loadMode, bool? destroy, double? volume, bool? looping, Duration? loopingStart, SoundPosition? position, bool? paused, double? relativePlaySpeed}) → SoundFromFile -
Allow sounds to be copied.
override
-
load(
) → Future< AudioSource> -
Load file.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited