SoundPosition3d class

Position for a 3d sound.

Implemented types

Constructors

SoundPosition3d(double x, double y, double z, {double velX = 0.0, double velY = 0.0, double velZ = 0.0, double minDistance = 1, double maxDistance = 10, bool tickWhenInaudible = false, bool killWhenInaudible = false})
Create an instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
killWhenInaudible bool
Whether to kill this sound when it becomes inaudible.
final
maxDistance double
The maximum distance at which this source will be heard.
final
minDistance double
The minimum distance at which the source will be heard.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tickWhenInaudible bool
Whether to keep ticking this sound if it becomes inaudible.
final
velX double
The velocity x coordinate.
final
velY double
The velocity y coordinate.
final
velZ double
The velocity z coordinate.
final
x double
The x coordinate.
final
y double
The y coordinate.
final
z double
THe z coordinate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited